---
title: <span class="badge object-type-scalar"></span> Kilopascals
---
# <span class="badge object-type-scalar"></span> Kilopascals

Pressure: Kilopascals

## Definition

```python
# Pressure: Kilopascals
Kilopascals: typing.Literal["pressurekpa"] = "pressurekpa"
```
